package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0,```````````(``P`!````X)D$"#0```#TMP```````#0`(``(
M`"@`'``;``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(Y+(`
M`.2R```%`````!````$```#DL@``Y$(%".1"!0B$`@``[!(```8`````$```
M`@```/BR``#X0@4(^$(%"!`!```0`0``!@````0````$````2`$``$B!!`A(
M@00(1````$0````$````!````%#E=&3PK```\"P%"/`L!0CL````[`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````2````
M!````!0````#````1TY5`,BCCJ_^&ZR@2`$3*R$[FGS\9T!P)0```$\````(
M````"``````0$`0E0`2`J!$``:*&0:A````"2R@$*3BB,D>*!`R(3P```%$`
M``````````````````!4````5@```%<`````````6````%D`````````6@``
M`%L```!<`````````%T```````````````````!>````80``````````````
M8@```&0```!E````9P````````!I````;`````````!N````;P```'````!Q
M`````````,C5LG%9Z.WLYO\PHL[>1RVCX/M)ZM/O#J?=HVLOQ9NVV\WCGH?Y
MG(%K"4/6#3J7"\6)!9`-%.*>(?_D#K(!BV_$N9Q`:W^:?'^IG)MNQ=\?V7%8
M'+OCDGS49-1\K4OCP#)BV^WAIP(*9J_,9F`6R5E[\$IKXD?&`4-%U>Q'[#,Z
M?4&.Q</E/RSRV],=^J%L8+F-\0X`````````````````````*0,`````````
M````$@```*P``````````````!(```"^`P`````````````2````J0,`````
M````````$@```)P!`````````````!(```#N`P`````````````2````=0(`
M````````````$@````P``````````````"`````;```````````````@````
MKP,`````````````$@```(@!`````````````!(````/!``````````````2
M````:0$`````````````$@```'L!`````````````!(```!@`P``````````
M```2````.@,`````````````$@```"<"`````````````!(```#X````````
M```````2````%P(`````````````$@```-,#`````````````!(```#%`0``
M```````````2````>00`````````````$@```#X$`````````````!(````(
M`P`````````````2````0@,`````````````$@```),"`````````````!(`
M``#E`0`````````````2````H0$`````````````$@```#`"````````````
M`!(```#\`P`````````````2````:P0`````````````$@```"H!````````
M`````!(````'!``````````````2````+P``````````````$@```!D$````
M`````````!(```!8`0`````````````2````PP``````````````$@```$L$
M`````````````!(```#G`P`````````````2````-P0`````````````$@``
M`,P#`````````````!(```"B`P`````````````2````;04`````````````
M$@```#P!`````````````!(````G!``````````````2````5P(`````````
M````$@```(@#`````````````!(````<`P`````````````2````20(`````
M````````$@```-H#`````````````!(```",`@`````````````2````I@$`
M````````````$@```)$#`````````````!(```#A`P`````````````2````
MQ0,`````````````$@```.<``````````````!(````]```````````````2
M````+@0`````````````$@```&,$`````````````!(```#2````````````
M```2````^0$`````````````$@```(`"`````````````!(```!+`0``````
M```````2````500`````````````$@```+<#`````````````!(```!W`P``
M```````````2````(@,`````````````$@```!@!`````````````!(````^
M`@`````````````2````3P``````````````$@```-,!`````````````!(`
M``!>```````````````2````<@0`````````````$@```(H`````````````
M`!(```!_`P`````````````2````<@,`````````````$@```',`````````
M`````!(````&`0`````````````2````L@$``%"5!`@`````$@````X%``!@
MS@0(!````!$`#P#7!0``@-,$"&Y9```1``\`X04``("Z!`C<"```$@`-``T&
M````LP0(=0$``!(`#0`(!0``+,X$"``````2``X`C00``(!%!0@$````(0`9
M`.`$``#0KP0(#0```!(`#0"F!0``H,T$"%H````2``T`FP```""7!`@`````
M$@```)$%``!8104(`````!``&`"3!0``6$4%"``````@`!@`C`0``(!%!0@$
M````(0`9`/X$``"0S00(!0```!(`#0``!@``4+@$""@"```2``T`*P4``&"H
M!`A$````$@`-`(L$``"`104(!````!$`&0"&!```,+8$"!@"```2``T`6P4`
M`("T!`@@````$@`-`'8%``"PM00(?@```!(`#0"<!```:$4%"``````0`/'_
MJ`0``-!5!0@`````$`#Q_Q4%``!@PP0(,@D``!(`#0!1`P``9,X$"`0````1
M``\`EP4``."9!`@`````$@`-`#D%````KP0(Q````!(`#0!/!0``H+0$"!`!
M```2``T`@@4``&1%!0@$````$0`8`&4"```0EP0(`````!(```#Q!```H)H$
M"#,````2``T`E00``&A%!0@`````$`#Q_](%``!@104(!````!$`&`"V!0``
M\*D$"%T````2``T`G@4``*#,!`@_````$@`-`)X"``"$104($P```!$`&0#N
M!0``T+$$""@!```2``T`H`4``*"4!`@`````$@`+``!L:6)P97)L+G-O`%]?
M9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`4&5R;%]S>7-?=&5R
M;0!097)L7TES=&%T8G5F7W!T<@!097)L7W-Y<U]I;FET,P!097)L7TEE>&ET
M7V9L86=S7W!T<@!097)L7W-A=F5?9&5S=')U8W1O<E]X`%!E<FQ?26-O;7!C
M=E]P='(`4&5R;%]A=&9O<FM?;&]C:P!097)L7TEC=7)S=&%C:VEN9F]?<'1R
M`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?27!A
M<G-E<E]P='(`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L
M7TET;W!?96YV7W!T<@!097)L7TET86EN=&5D7W!T<@!097)L7W-V7W-E='!V
M;@!097)L7VYE=U-6<'8`4&5R;%]N97=84U]F;&%G<P!097)L7TEI;E]E=F%L
M7W!T<@!097)L7TEO<%]P='(`4&5R;%])979A;%]R;V]T7W!T<@!P97)L7V9R
M964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T
M<'8`4&5R;%]'=&AR7VME>5]P='(`4&5R;%]'9&]?=6YD=6UP7W!T<@!097)L
M7TEP97)L7V1E<W1R=6-T7VQE=F5L7W!T<@!097)L7V=V7V9E=&-H<'8`<&5R
M;%]R=6X`4&5R;%]D;W5N=VEN9`!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`
M4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L
M7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)R
M97-O;'8N<V\N,@!L:6)N<VPN<V\N,0!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L
M:6)C<GEP="YS;RXQ`&QI8G5T:6PN<V\N,0!L:6)P=&AR96%D+G-O+C``<'1H
M<F5A9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO
M;@!L<V5E:S8T`')E860`;&EB8RYS;RXV`%])3U]S=&1I;E]U<V5D`%]?<F5G
M:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?
M7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G
M971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`&UE;6-P
M>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`
M7U]C='EP95]B7VQO8P!G971U:60`<F5A9&QI;FL`97AE8W9P`%]?;65M8W!Y
M7V-H:P!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S
M=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S
M<U]S=&%R=`!?96YD`"]U<W(O;&EB+W!E<FPU+S4N,3`N,"]I,S@V+6QI;G5X
M+71H<F5A9"UM=6QT:2]#3U)%`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N
M86UE`%]?;&EB8U]C<W5?9FEN:0!?9G!?:'<`6%-?26YT97)N86QS7U!!4E]"
M3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D
M:7)N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`'-I>F5?;&]A9%]M95\R`%]?9&%T85]S=&%R=`!X<U]I;FET`%]?;&EB8U]C
M<W5?:6YI=`!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`;F%M95]L;V%D
M7VUE7S(`<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD
M<')O9P!P87)?:6YI=%]E;G8`1TQ)0D-?,BXT`$=,24)#7S(N,P!'3$E"0U\R
M+C,N,@!'3$E"0U\R+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXP`````@````,`
M`P````0``````````P````4```````8`!P`````````#`````P`$``(``@``
M`````P````4``P````,````(```````%``,``P`#``,``P````,````#``(`
M```#``,````)``,``P```````P`#````````````!``#``,`!P``````````
M`````P````,``P`````````!``$``0`!``$``P`!``$````!``$``P`!``$`
M`0`#``$``0`!``$``0`!``$``0`!``$``0````$``0`!``$``0````$``0``
M``$`!@!'`P``$````'`````4:6D-```)`!H&```0````$VEI#0``"``D!@``
M$````'(9:0D```8`+@8``!`````2:6D-```%`#H&```0````=!EI"0``!`!$
M!@``$````!!I:0T```,`4`8````````!``(`^`(``!``````````$FEI#0``
M!P`Z!@``$````!!I:0T```(`4`8````````(1`4(!@@``(!%!0@%7P``A$4%
M"`5Q```81`4(!P$``!Q$!0@'`@``($0%"`<#```D1`4(!P0``"A$!0@'!0``
M+$0%"`<&```P1`4(!P<``#1$!0@'3P``.$0%"`<(```\1`4(!PH``$!$!0@'
M"P``1$0%"`<,``!(1`4(!PT``$Q$!0@'#@``4$0%"`</``!41`4(!Q```%A$
M!0@'$0``7$0%"`<2``!@1`4(!Q,``&1$!0@'%```:$0%"`<5``!L1`4(!Q8`
M`'!$!0@'%P``=$0%"`<8``!X1`4(!QD``'Q$!0@'&@``@$0%"`<;``"$1`4(
M!QP``(A$!0@''0``C$0%"`<>``"01`4(!Q\``)1$!0@'(```F$0%"`<A``"<
M1`4(!R(``*!$!0@'(P``I$0%"`=K``"H1`4(!U@``*Q$!0@')```L$0%"`<E
M``"T1`4(!R8``+A$!0@')P``O$0%"`<H``#`1`4(!RD``,1$!0@'*@``R$0%
M"`<K``#,1`4(!RP``-!$!0@'+0``U$0%"`<N``#81`4(!R\``-Q$!0@',```
MX$0%"`<Q``#D1`4(!S(``.A$!0@',P``[$0%"`<T``#P1`4(!S4``/1$!0@'
M-@``^$0%"`<W``#\1`4(!S@```!%!0@'.0``!$4%"`<Z```(104(!SL```Q%
M!0@'/```$$4%"`<]```4104(!SX``!A%!0@'/P``'$4%"`=````@104(!T$`
M`"1%!0@'0@``*$4%"`=#```L104(!T0``#!%!0@'10``-$4%"`=&```X104(
M!T<``#Q%!0@'2```0$4%"`=)``!$104(!TH``$A%!0@'2P``3$4%"`=,``!0
M104(!TT``%1%!0@'3@``58GE4X/L!.@`````6X'#8*\``(N3_/___X72=`7H
MG@```.BI!0``Z#0Y``!86\G#_S401`4(_R441`4(`````/\E&$0%"&@`````
MZ>#_____)1Q$!0AH"````.G0_____R4@1`4(:!````#IP/____\E)$0%"&@8
M````Z;#_____)2A$!0AH(````.F@_____R4L1`4(:"@```#ID/____\E,$0%
M"&@P````Z8#_____)31$!0AH.````.EP_____R4X1`4(:$````#I8/____\E
M/$0%"&A(````Z5#_____)4!$!0AH4````.E`_____R5$1`4(:%@```#I,/__
M__\E2$0%"&A@````Z2#_____)4Q$!0AH:````.D0_____R501`4(:'````#I
M`/____\E5$0%"&AX````Z?#^____)5A$!0AH@````.G@_O___R5<1`4(:(@`
M``#IT/[___\E8$0%"&B0````Z<#^____)61$!0AHF````.FP_O___R5H1`4(
M:*````#IH/[___\E;$0%"&BH````Z9#^____)7!$!0AHL````.F`_O___R5T
M1`4(:+@```#I</[___\E>$0%"&C`````Z6#^____)7Q$!0AHR````.E0_O__
M_R6`1`4(:-````#I0/[___\EA$0%"&C8````Z3#^____)8A$!0AHX````.D@
M_O___R6,1`4(:.@```#I$/[___\ED$0%"&CP````Z0#^____)91$!0AH^```
M`.GP_?___R681`4(:``!``#IX/W___\EG$0%"&@(`0``Z=#]____):!$!0AH
M$`$``.G`_?___R6D1`4(:!@!``#IL/W___\EJ$0%"&@@`0``Z:#]____):Q$
M!0AH*`$``.F0_?___R6P1`4(:#`!``#I@/W___\EM$0%"&@X`0``Z7#]____
M);A$!0AH0`$``.E@_?___R6\1`4(:$@!``#I4/W___\EP$0%"&A0`0``Z4#]
M____)<1$!0AH6`$``.DP_?___R7(1`4(:&`!``#I(/W___\ES$0%"&AH`0``
MZ1#]____)=!$!0AH<`$``.D`_?___R741`4(:'@!``#I\/S___\EV$0%"&B`
M`0``Z>#\____)=Q$!0AHB`$``.G0_/___R7@1`4(:)`!``#IP/S___\EY$0%
M"&B8`0``Z;#\____)>A$!0AHH`$``.F@_/___R7L1`4(:*@!``#ID/S___\E
M\$0%"&BP`0``Z8#\____)?1$!0AHN`$``.EP_/___R7X1`4(:,`!``#I8/S_
M__\E_$0%"&C(`0``Z5#\____)0!%!0AHT`$``.E`_/___R4$104(:-@!``#I
M,/S___\E"$4%"&C@`0``Z2#\____)0Q%!0AHZ`$``.D0_/___R40104(:/`!
M``#I`/S___\E%$4%"&CX`0``Z?#[____)1A%!0AH``(``.G@^____R4<104(
M:`@"``#IT/O___\E($4%"&@0`@``Z<#[____)21%!0AH&`(``.FP^____R4H
M104(:"`"``#IH/O___\E+$4%"&@H`@``Z9#[____)3!%!0AH,`(``.F`^___
M_R4T104(:#@"``#I</O___\E.$4%"&A``@``Z6#[____)3Q%!0AH2`(``.E0
M^____R5`104(:%`"``#I0/O___\E1$4%"&A8`@``Z3#[____)4A%!0AH8`(`
M`.D@^____R5,104(:&@"``#I$/O___\E4$4%"&AP`@``Z0#[____)51%!0AH
M>`(``.GP^O__,>U>B>&#Y/!05%)HD,T$"&B@S00(459H,+8$".@O_/__])"0
MD)"0D)"0D)"0D)"058GE4XUD)/R`/9A%!0@`=3Z[\$(%"*&<104(@>OL0@4(
MP?L"@^L!.=AS'9"-="8`@\`!HYQ%!0C_%(7L0@4(H9Q%!0@YV'+HQ@68104(
M`8UD)`1;7<.-=@"-O"<`````58GEC60DZ*'T0@4(A<!T$K@`````A<!T"<<$
M)/1"!0C_T,G#D)"0D)"0D)"0D)"058GE5E.+=0B)\`^V#H3)=!ZA4-`$"(U6
M`0^V&(GP9I`XV0^V"@]$PH3)C5(!=?%;7EW#C;8`````C;PG`````%4QTHGE
M5XG'5H/''(VUM/[__U.-I"2P_O__B86L_O__BPR7B<B)R\'C&,'H&`G8B<O!
MXPB!XP``_P#!Z0@)V('A`/\```G(B026C5(!@_H0=<Z-E>C^__^-3>B0C70F
M`(M"[#,",T+4,T+,P<@?B4(,C5($.<IUZ(N5K/[__XN%K/[__XG1BP")A:C^
M__^+01"+C:C^__\#A;3^___!R1N+<@2+>@B+4@R)^R'SC8P(F7F"6HGP]]`A
MT`.5N/[__PG8BYVH_O__`<&+A:C^___!S@+WT"'S(?@)V`.]O/[__XN=J/[_
M_\'+`HV4`IEY@EJ)R,'(&P'"B=#!R!N-A`>9>8):B86D_O__B<B)S_?0(=\A
M\`.UP/[__PGX`X6D_O__B;6D_O__B=;!R0*)U_?6(<\AW@.=Q/[__PG^B[VD
M_O__P<H"C;0WF7F"6HFUL/[__XG&P<X;`[6P_O__B??!SQN-O#N9>8):B<.)
MO:3^___WTXG'(<LAUPG[`YVD_O__`XW(_O__B?>)C:3^__^)\<'(`O?1(<<A
MT0GYB[VD_O__`Y7,_O__P<X"C8P/F7F"6HF-L/[__XG9P<D;`XVP_O__B<_!
MSQN-O#J9>8):B=J)O:3^___WTHG?(<(A]P.%T/[__PGZ`Y6D_O__B86D_O__
MB<C!RP*)S_?0(=\A\`.UU/[__PGXB[VD_O__P<D"C80'F7F"6HF%L/[__XG0
MB[VP_O__P<@;`<>)^,'(&XV$!IEY@EJ)A:3^__^)T(G6]]`ASB'8`YW8_O__
M"?`#A:3^__^)G:3^__^)^\'*`HG^]],AUB'+"?.+M:3^__\#C=S^___!SP*-
MG!Z9>8):B9VP_O__B</!RQL#G;#^__^)WL'.&XVT,9EY@EJ)P8FUI/[___?1
MB<8AT2'^`Y7@_O__"?$#C:3^__^)E:3^__^)VL'(`HG>]](AQB'Z`[WD_O__
M"?*+M:3^___!RP*-E!:9>8):B96P_O__B<J+M;#^___!RAL!UHGRP<H;C907
MF7F"6HF5I/[__XG*B<_WTB'?(<(#A>C^__\)^@.5I/[__XF%I/[__XGPP<D"
MB??WT"'/(=@#G>S^__\)^(N]I/[__\'.`HV$!YEY@EJ)A;#^__^)T(N]L/[_
M_\'(&P''B?C!R!N-A`.9>8):B86D_O__B=")T_?0(?,AR`.-\/[__PG8`X6D
M_O__B8VD_O__B?G!R@*)^_?1(=,A\0G9BYVD_O__P<\"C8P+F7F"6HF-L/[_
M_XG!BYVP_O__P<D;`[7T_O__`<N)V<')&XV,#IEY@EJ)C:3^__^)P8G&]]$A
M_B'1`Y7X_O__"?$#C:3^__^)E:3^__^)VL'(`HG>]](AQB'Z`[W\_O__"?*+
MM:3^___!RP*-E!:9>8):B96P_O__B<J+M;#^___!RAL!UHGRP<H;C907F7F"
M6HF5I/[__XG*B<_WTB'?(<()^@.5I/[__\')`@.%`/___XF%I/[__XGPB??W
MT"'/(=@)^(N]I/[__\'.`@.=!/___XV$!YEY@EJ)]S'/B86P_O__,=>)T,'(
M&P.%L/[__\'*`@.-"/___XV\.Z'KV6Z)P\'+&P'[B=<Q]P.U#/___S''P<@"
MC;PYH>O9;HG9P<D;`?F)QS'7`Y40____,=_!RP*-O#ZAZ]ENB<[!SAL!_HG?
M,<<#A13___\QS\')`HV\.J'KV6Z)\L'*&P'ZB<\QWP.=&/___S'WP<X"C;PX
MH>O9;HG0P<@;`<>)\#'(`XT<____,=#!R@*-G`.AZ]ENB?C!R!L!V(G3,?,#
MM2#___\Q^\'/`HV<&:'KV6Z)P<')&P'+B?DQT0.5)/___S'!P<@"C;0.H>O9
M;HG9P<D;`?&)QC'^`[TH____,=[!RP*-M#*AZ]ENB<K!RAL!UHG:,<(QRHV\
M%Z'KV6Z)\L'*&P'Z`X4L____P<D"B<\QWP.=,/___S'WP<X"C;PXH>O9;HG0
MP<@;`<>)\#'(`XTT____,=#!R@*-G`.AZ]ENB?C!R!L!V(G3,?,#M3C___\Q
M^\'/`HV<&:'KV6Z)P<')&P'+B?DQT0.5//___S'!P<@"C;0.H>O9;HG9P<D;
M`?&)QC'^`[U`____,=[!RP*-M#*AZ]ENB<K!RAL!UHG:,<(#A43___\QRL')
M`HV\%Z'KV6Z)\L'*&P'ZB<\QWP.=2/___S'WP<X"C;PXH>O9;HG0P<@;`<>)
M\#'(`XU,____,=#!R@*-G`.AZ]ENB?C!R!L!V(G3,?,#M5#___\Q^\'/`HV<
M&:'KV6Z)P<')&P'9B?LQTP.55/___S'#B96D_O__P<@"B<(A^HVT'J'KV6Z)
MR\'+&P'SB<8)_B'."=:+E:3^___!R0(#O5C___^)O:3^__^)SR''C;0RW+P;
MCXG:P<H;`?*)S@G&`X5<____(=X)_HN]I/[__\'+`HF%I/[__XG8(<B-M#?<
MO!N/B=\)SXFUL/[__R'7B=8)QXN%I/[__\'.&P.UL/[__\'*`@.-8/___XF-
MI/[__XG1C;PXW+P;CXGPP<@;(=D!^(G7"=\#G63___\A]PG/BXVD_O__P<X"
MB9VD_O__B?,ATXV\.=R\&X^)P<')&P'YB?<)UR''"=^+G:3^__^-O#O<O!N/
MB<O!RQL#E6C____!R`(!^XG'B96D_O__"?>)PB'R(<\)UXN5I/[__\')`@.U
M;/___XFUI/[__XG.(<:-O#K<O!N/B=K!RAL!^HG/"<<#A7#___\AWPGWB[6D
M_O__P<L"B86D_O__B=@AR(V\/MR\&X^)UL'.&P'^B=\)SP.-=/___R'7"<>+
MA:3^___!R@*)C:3^__^)T2'9C;PXW+P;CXGPP<@;`?B)UPG?(?<)SXN-I/[_
M_XV\.=R\&X^)P<')&P'Y`YUX____P<X"B9VD_O__B?>)\PG7(=,AQP.5?/__
M_PG?BYVD_O__P<@"B96D_O__B<(A\HV\.]R\&X^)R\'+&P'[B<<)]P-U@"'/
M"=>+E:3^___!R0*)M:3^__^)SB'&C;PZW+P;CXG:P<H;`?J)SPG'`T6$(=\)
M]XNUI/[__\'+`HF%I/[__XG8(<B-O#[<O!N/B=;!SAL!_HG?"<\AUPG'BX6D
M_O__C;PXW+P;CXGPP<@;`?C!R@(#38B)UXF-I/[__PG?B=$AV2'W"<^+C:3^
M___!S@(#78R)G:3^__^)\R'3C;PYW+P;CXG!P<D;`?F)]PG7`U60(<<)WXN=
MI/[__\'(`HF5I/[__XG"(?*-O#O<O!N/B<O!RQL!^XG'"?<#=90ASPG7BY6D
M_O__P<D"B;6D_O__B<XAQHV\.MR\&X^)VL'*&P'ZB<\)QR'?"?>+M:3^___!
MRP*-O#[<O!N/B=;!SAL!_@-%F(G?B86D_O__"<^)V"'((=<)QXN%I/[__\'*
M`@--G(F-I/[__XG1(=F-O#C<O!N/B?#!R!L!^(G7"=\#7:`A]PG/BXVD_O__
MP<X"B9VD_O__B?,ATXV\.=R\&X^)P<')&P'/B?$)T0-5I"'!"=F+G:3^___!
MR`*-C`O<O!N/B<,Q\XF-L/[__S'[B?G!R1L#C;#^___!SP(#=:B-G!K6P6+*
MB<K!RAL!TXGZ,<(QRHVT%M;!8LJ)VL'*&P-%K,')`@'RB<XQ_@-]L#'>P<L"
MC;0PUL%BRHG0P<@;`<:)V#'(`TVT,=#!R@*-O`?6P6+*B?#!R!L!^(G7,=\#
M7;@Q]\'.`HV\.=;!8LJ)P<')&P'/B?$QT0-5O#'!P<@"C9P+UL%BRHGYP<D;
M`=F)PS'S,?O!SP*-G!K6P6+*B<K!RAL!TXGZ`W7`,<(QR@-%Q,')`HVT%M;!
M8LJ)VL'*&P'RB<XQ_@-]R#'>P<L"C;0PUL%BRHG0P<@;`<:)V#'(`TW,,=#!
MR@*-O`?6P6+*B?#!R!L!^(G7,=\#7=`Q]\'.`HV\.=;!8LJ)P<')&P'/B?$Q
MT0-5U#'!P<@"C9P+UL%BRHGYP<D;`=F)PS'S,?N-G!K6P6+*B<K!RAL#==C!
MSP(!TXGZ,<(#1=PQRL')`HVT%M;!8LJ)VL'*&P'RB<XQ_@-]X#'>P<L"C;0P
MUL%BRHG0P<@;`<:)V#'(`TWD,=#!R@*-O`?6P6+*B?#!R!L!^(G7,=\#7>@Q
M]\'.`HV\.=;!8LJ)P<')&P'YB?<QUS''P<@"C;P[UL%BRHG+P<L;`?N)QP-5
M[#'W,<_!R0*-O#K6P6+*B=K!RAL!UXN5J/[__P-5\(VT%M;!8LJ)RC'",=H!
M\HG^P<X;`?*+M:S^___!RP*)%@%^!`%>"`%.#`%&$(VD)%`!``!;7E]=PY"-
M="8`58GEC60DR(7`B5WTB77XB7W\B<.)5=QU#S'`BUWTBW7XBWW\B>Q=PZ&`
M104(A<")1>!TY0^V`SP]=%6$P(G:=$^-4@$/M@(\/70$A,!U\BG:BT7@BS"%
M]G2_B5WDB<>)TXVT)@````"+1>2)7"0(B40D!(DT).@%\?__A<!U!H`\'CUT
M$XU_!(LWA?9UVNN),=+KO8UT)@"+1=PK?>#!_P*).(U$'@'I;____XUT)@!5
MB>6-9"3HC57TZ$'____)P^L-D)"0D)"0D)"0D)"0D%6)Y8UD)/BA7$4%"(/X
M_W0'R<.0C70F`+ALS@0(Z+[___^%P'0:#[8`A,!T$SPP#Y7`#[;`HUQ%!0C)
MPXUT)@`QP.OQC;8`````C;\`````58GE5HG&4XU=](UD)/#K&(M%],'@`@,%
M@$4%"(U`!(L0A=*)4/QU](G:B?#HK_[__X7`==N-9"006UY=PXUV`%6)Y8VD
M)+CO___'1"0(_P\``,<$)';.!`AEH10```")1>0QP(E=](EU^(E]_(G3B8W4
M[___C;WD[___B7PD!.A<[___A<")QGYVC4#_@+P%Y.___P!T88ET)`C'1"0$
M+P```(D\).BE[___A<!T4<<$)`````#H]>___XL`B00DZ-OL__^)!"2)="0,
MB7PD"(E<)`3H)^[__XM%Y&4S!10```!U28M=](MU^(M]_(GL7<.-M@````"%
MP'0$B<;KE\<$)`````#HI.___XL`B00DZ(KL__^+E=3O__^)7"0$B50D"(D$
M).A$[/__ZZOH7>[__XVV`````(V\)P````!5B>6-9"3HQP0D`````.A=[___
MBP")!"3H0^S__XD$),=$)`3_____Z(/L___'!"0`````Z#?O__^+`(D$).@=
M[/__B00DQT0D"`````#'1"0$4*H$".AU[___R<.-=@!5B>53C60D[,<$)```
M``#H_.[__XL`B00DZ.+K__^)!"3H>NK__XL`BU@$QP0D`````.C9[O__BP")
M!"3HO^O__XD$).@'Z___#[8`B$,8QP0D`````.BU[O__BP")!"3HF^O__XD$
M).@SZO__BP"+6`3'!"0`````Z)+N__^+`(D$).AXZ___B00DZ-#J__^+``^W
M0!!F)?\!9HE#&L<$)`````#H9N[__XL`B00DZ$SK__^)!"3HY.G__XL`BU@$
MQP0D`````.A#[O__BP")!"3H*>O__XD$),=$)`@`````QT0D!.7/!`CHH>W_
M_XE#',<$)`````#H$N[__XL`B00DZ/CJ__^)!"3HD.G__XL`BU@$QP0D````
M`.CO[?__BP")!"3HU>K__XD$).C]Z?__BP")0R#'!"0`````Z,SM__^+`(D$
M).BRZO__B00DZ$KI__^+`(M8!,<$)`````#HJ>W__XL`B00DZ(_J__^)!"3H
MI^S__XL`,=*%P'0CQP0D`````.B#[?__BP")!"3H:>K__XD$).B![/__BP"+
M4&R)4R3'!"0`````Z%WM__^+`(D$).A#ZO__B00DZ-OH__^+`(M`!,=`*```
M``#'!"0`````Z#/M__^+`(D$).@9ZO__B00DZ+'H__^+`(M`!,=`+`````#'
M!"0`````Z`GM__^+`(D$).COZ?__B00DZ(?H__^+`(M8!,<$)`````#HYNS_
M_XL`B00DZ,SI__^)!"3HI.S__XL`B4,PC60D%%M=PY"-M"8`````58GE5XG'
M5E.-I"1D____A<!T!8`X`'40C:0DG````%M>7UW#C70F`(D$).@0ZO__A<")
MQG3B9I")-"3H<.K__X7`#X30````C5@3#[85ALX$"`^V0!,YT`^$V@````^V
M%87.!`@YT`^$XP```(D\).AKZO__B1PDB46`Z&#J__^+58"-1`("B00DZ/'J
M__^)182)7"04B7PD$,=$)`R(S@0(QT0D"/_____'1"0$`0```(D$).B6Z___
MC46(B40D"(M%A,<$)`,```")1"0$Z!SH__^#^/]T$XM%F"4`\```/0!````/
MA(P```"+182)!"3H^>G__XM%A(D$).CNZ/__B30DZ*;I__^%P`^%-O___XVV
M`````(DT).@@ZO__B3PDZ(CJ__^-I"2<````6UY?7<.-="8`#[93`3H5A\X$
M"`^$\/[__^D1____C78`#[9#`3H%ALX$"`^%#?___P^V0P(Z!8?.!`@/A,C^
M___I^/[__XUV`(M%A.B`_O__Z7+___^-="8`C;PG`````%6)Y5.)PXUD).S'
M!"0`````Z!KK__^+`(D$).@`Z/__B00DZ"CJ__^)1"0(B5PD!,<$)`,```#H
M1.C__X7`=!"-9"04,<!;7<.-M"8`````QP0D`````.C4ZO__BP")!"3HNN?_
M_XD$).CBZ?__BT`0)0#P```]`$```'0MQP0D`````.BGZO__BP")!"3HC>?_
M_XD$).BUZ?__BT`0)0#P```]`*```'66B1PDQT0D!`(```#HUN?__X7`#Y3`
MC60D%`^VP%M=PXVT)@````!5B>6-I"2XW___9:$4````B47D,<")7?2)=?B)
M??R-G>/O___HU^7__XE$)!#'1"04@<X$",=$)`R.S@0(QT0D"`$0``#'1"0$
M`0```(D<).B;Z?__A<!Y'S';BU7D93,5%````(G8=5:+7?2+=?B+??R)[%W#
M9I#'1"0(`!```(V]XM___XD<)(E\)`3H_NC__X7`B<9XP8U``8D$).A]Z/__
MA<")PW2RB70D"(E\)`2)!"3HI^?__\8$,P#KG.A\Z/__C;8`````C;\`````
M58GEC60D^,GI(____XUV`%6)Y5=6B<8QP%.)TXUD),2`.CT/E,`!PXD<).B`
MY___B<>-5>2)\.B$]___A<!T.(D$)(E%T.AEY___,<DYQXM5T`^'B`$```^V
M!`N$P(@$"HU)`77RC60D/#'`6UY?7<.-M"8`````H8!%!0@QTKD(````@S@`
M=!B-M"8`````C5(!BPR0A<EU]HT,E0@```"#/:!%!0@`=#:)3"0$B570B00D
MZ.?D__^%P(G!HX!%!0B+5=`/A2,!``"-9"0\N/____];7E]=PXVT)@````")
M#"2)5=#'!:!%!0@!````Z%OG__^%P(G!BU70=,V-!)4`````B474B40D"*&`
M104(B0PDB4W,B40D!.BPY___BTW,BU70B0V`104(QT21!`````")5>0/MA:`
M^CT/A)D```"$THGP#X2/````C78`C4`!#[80@/H]=`2$TG7Q*?"+5=0#%8!%
M!0B-1#@"B570B00DZ-?F__^+5="%P(D"#X1%____BU7DH8!%!0B+!)`/MA:$
MTH@0="*`^CUT'8UV`>L)C70F`(#Z/70/#[86C4`!A-*($(UV`77LQ@`],=*-
MM"8`````#[8,$X3)B$P0`8U2`77QZ8K^__\QP.N!BT7DP>`"B474Z4G___^-
M!)4`````B474Z2____^-=@!5B>57OZ3.!`A6C7784[N:S@0(C60DE,=%T*3.
M!`C'1=2:S@0(QT78I\X$",=%W)W.!`C'1>"BS@0(QT7DY<\$".LID(UT)@"+
M10B)%"2)1"0$B56\Z.;E__^%P'0Z@#L`="J+!HG?C78$B<.)^.C]]?__A<")
MPG0%@#@`=<J+50B)^.B(_?__@#L`==:-9"1L6UY?7<-FD(M-"(D,).@-Y?__
MB47$H530!`B)!"3H_>3__XM5O(E%P(D4).COY/__B46TBTW`BT7$C4P(`HM%
MM`'(B00DZ'7E__^)P:%4T`0(BU6\B40D%(M%"(E4)!B)#"2)3;R)1"00QT0D
M#)[/!`C'1"0(_____\=$)`0!````Z`GF__^+3;R)^(G*Z.W\___I-O___Y"-
MM"8`````58GE5U:-9"309:$4````B47T,<"A+-`$"(E%TJ$PT`0(B476H330
M!`B)1=JA.-`$"(E%WJ$\T`0(B47BH4#0!`B)1>:A1-`$"(E%ZJ%(T`0(B47N
M#[<%3-`$"&:)1?*XM,X$".A']?__N,3.!`CH/?7__[C0S@0(Z#/U__^X;,X$
M".@I]?__N-G.!`CH'_7__[CCS@0(Z!7U__^X[<X$".@+]?__N/K.!`CH`?7_
M_[@#SP0(Z/?T__^X#L\$".A]]/__A<!T#(G"N-G.!`CH#?S__[@?SP0(Z&/T
M__^%P'0,B<*X,<\$".CS^___N#S/!`CH2?3__X7`=#6)PKC0S@0(Z-G[__^Z
M:,\$"+BTS@0(Z,K[__^+1?1E,P44````=4Z-9"0P7E]=PXVV`````+A,SP0(
MZ`;T__^%P'02B<*X;,X$".B6^___Z[N-="8`C77COUW/!`BY"@```/.F=::-
M5>VX;,X$".AR^___ZY?HR^/__XUT)@"-O"<`````58GEC60DZ.@TX___B00D
MZ`SC__^)PC'`A=)T`HL"R<-5B>564XUD)/"+70B%VW1@@#L`=%N)'"3HP^+_
M_XU$`_\YPP^#W````(LU4-`$"`^V"`^V%CC1=`OK69"-="8`.`AU4(U`_SG#
M<O4YV'51#[8`.@8/A(X```")=0B-9"006UY=Z9?D__^-M"8`````QP0D`@``
M`.@$X___A<!T!6;'`"X`C60D$%M>7<.-=@`X$'2WC4#_.<-R]3G8=+"0C4#_
M.<-S!P^V$#H6=/*)PC'`*=J-2@*!^0`0``!WQHU2`<=$)`P`$```B50D"(E<
M)`3'!"3`104(Z++?__^XP$4%".N@C78`QP0D`@```.B,XO__B<(QP(72=(EF
MQP(N`(G0ZX"+-5#0!`CI.____U6)Y5=64XUD).2+=0B)-"3HV_[__P^V"(G'
MA,F)PW0?H5#0!`B-5P$/M@"0C70F`#C!#[8*#T3:A,F-4@%U\>AL\O__A<!T
M'H7V=!J`/@"0=!3'1"0$:L\$"(D<).C^X?__.=AT"8UD)!Q;7E]=PXUD)!R)
M\%M>7UWI<O;__V:058GE@^3P5E.-11"-9"3(B40D"(U%#(E$)`2-10B)!"3H
M^^+__\=$)`A0E00(QT0D!%"5!`C'!"0@EP0(Z-\6``#'!"0`````Z`/@__^`
M.`!U.^CIW___A<"CP%4%"`^$J`$``(D$).BDX/__QP0D`````.BXXO__BP")
M!"3HGM___XD$).@&XO__Q@``QP0D`````.B7XO__BP")!"3H?=___XD$).B5
MXO__@`@"QP0D`````.AVXO__BP")!"3H7-___XD$).ATXO__@`@!BT4(@\`%
M,<F)1"0HB4PD+-]L)"C8!5S3!`C=!6#3!`C9R=_IW=@/AP4!``#!X`*)!"3H
MFN'__XMU#*/,504(BQ;'0`1OSP0(B1#'0`B`TP0(QT`,<L\$"(M="(/[`<<%
MR%4%"`0```!^%;H!````9I"+#):)3)`,C5(!.=-_\HU;`\<$F`````")1"0,
MH<!5!0B)7"0(QT0D$`````#'1"0$X,P$"(D$).B3W?__A<")PW0]H<!5!0B)
M!"3H0.#__[C$S@0(Z';P__^%P'0ZH<!5!0B)!"3H1=W__^@0W___C60D.(G8
M6UZ)[%W#C70F`*'`504(B00DZ./=__^)P^NRC;0F`````*'$504(A<!T"HD$
M).B7_?__Z[.XT,X$".@;\/__A<"CQ%4%"'2@Z^''!"2$104(Z'3@___'!"0!
M````Z&CA__^0C;0F`````%6)Y5=64XVD)+3O__^+10B)A=3O__^XT,X$"&6+
M%10```")5>0QTHMU#.C![___B<>+'5#0!`B+A=3O__^)7"0$B00DZ'??__^%
MP'0RBY74[___N.W.!`CH,_?__XM5Y&4S%10```"+A=3O__\/A;`!``"-I"1,
M$```6UY?7<.+E=3O__^)%"3HH][__XF%T.___Z%4T`0(B30DB40D!.ALW___
MA<")QG2CBY70[___@\(!B970[___C;0F`````(`^`+B&S@0(#T3PA?]T%(ET
M)`2)/"3H5>#__X7`#X39````B30DZ$7>__\/ME0&_SH3=1:-%`:0QD+_`(U`
M_P^V2OXZ"XU2_W3N`X70[___/?\/```/CS+___^+E=3O__^-A>3O__^)5"08
MB5PD%(ET)!#'1"0,GL\$",=$)`@`$```QT0D!`$```")!"3H3=___\<$)```
M``#HL=___XL`B00DZ)?<__^)!"3HO][__XE$)`B-E>3O___'!"0#````B50D
M!.BUV___A<!U+<<$)`````#H==___XL`B00DZ%O<__^)!"3H@][__XM`$"4`
M\```/0"```!T)*%4T`0(QP0D`````(E$)`3H/][__X7`B<8/A>7^___I;?[_
M_XV%Y.___\=$)`0!````B00DZ'K<__^%P'7"C97D[___N.W.!`CHAO7__XV5
MY.___XD4).@XW___B874[___Z3K^___HR-W__Y"-M"8`````58GE5U93C:0D
MQ'[__XM%"(F%!'___[C0S@0(98L5%````(E5Y#'2QX4H?___=<\$",>%+'__
M_WW/!`C'A3!___^&S@0(QX4T?___Y<\$",>%$'___S'/!`C'A11___\JSP0(
MQX48?___@L\$",>%''___WC/!`C'A2!___^*SP0(QX4D?___Y<\$",>%.'__
M_X[/!`C'A3Q___^3SP0(QX5`?___Y<\$".@2[?__A<!T"8`X``^%C0(``)"-
M="8`Z#OY__^%P(G'#X2A`@``#[8?A-MT(NBEV___B?J-=@"+"`^^V_8$60AU
M`\8"7XU2`0^V&H3;=>B-G11___^X,<\$".L1C78`BP.-6P2`.``/A/(!``#H
MI>S__X7`B<9TY^B*\O__A<!TWHDT).CNW?__A<!TTHG&B30DZ,#;__^)PXD\
M).BVV___C80#!`0``(D$).A'W/__B<.)?"0<BSU0T`0(B84`?___QT0D&&K/
M!`B)?"04B70D$,=$)`R<SP0(QT0D"/_____'1"0$`0```(D$).C5W/__QT0D
M!.T!``")'"3HY=C__[B=S@0(Z`OL__^%P`^$\P$``(D$).A;W?__BY4$?___
MB40D!(L"B00DZ/?[__^%P(G&#X3-`0``Z/CK__^%P'4>QT0D!`````")-"3H
MI-S__X7`B84$?___#X6V`0``B1PD,?_H[-K__XG&NFC/!`BX;,X$".@[\___
MZ%;8__^)1"08H5#0!`C'1"0<Y<\$"(E$)!2)7"00QT0D#+G/!`C'1"0(____
M_\=$)`0!````B1PDZ`W<___K5XUV`.CSU___@S@1=5_&!#,`C7\!Z`+8__^+
M%5#0!`C'1"0@Y<\$"(E\)!R)1"08B50D%(E<)!#'1"0,Q\\$",=$)`C_____
MQT0D!`$```")'"3HM-O__\=$)`3M`0``B1PDZ,37__^#^/]TEXG:N-#.!`CH
M@_+__XD<).AK]/__BWWD93,]%````(N%`'___P^%W`4``(VD)#R!``!;7E]=
MPY"-M2Q___^[=<\$".L-C78`BQZ-=@2`.P!T&XG8Z(?P__\QTH7`=.F)'"3H
MZ=O__X7`B<)TVXG6Z?3]__^-="8`B00DB87X?O__Z/KS__^+A?A^__^)!"3H
MO-O__XF%`'___^EV____D(V=/'___[B.SP0(D(UT)@#H.^K__X7`=!")!"3H
MC]O__X7`#X4W!0``BP.-6P2`.`!UW;_8SP0(Z4O]__^-=@"+O01___^+-^DF
M_O__C78`QT0D#`(```#'1"0$[O___\=$)`C_____B00DZ'#7__^+E01___^-
MA41____'1"0(!@```(E$)`2)%"3HX-?__X"]1'___P!U#8"]17___T,/A#,$
M``"-A6#____'A43___\!(T5GQX5(____B:O-[\>%3/____[<NIC'A5#___]V
M5#(0QX54____\.'2P\>%6/___P````#'A5S___\`````QT6@`````(F%]'[_
M_XF=_'[__XUV`(N%!'___\=$)`@`@```C;U$?___B00DB7PD!.A(U___A<")
MPP^.?@$``(N-6/___XN%7/___XV]1'___XT4V8F56/___SG*@]``B85<____
MB=C!Z!T!A5S___^+1:"%P'16OT````"-E6#___\IQSG[#T[[`=")?"0(C95$
M?___B00DB50D!.C<U___BT6@`?B#^$")1:`/A6/___^-A41___\I^P''C85$
M____Z#;;__^-M@````"#^S\/CKP````Q]I"-="8`BP0WB85@____BT0W!(F%
M9/___XM$-PB)A6C___^+1#<,B85L____BT0W$(F%</___XM$-Q2)A73___^+
M1#<8B85X____BT0W'(F%?/___XM$-R")18"+1#<DB46$BT0W*(E%B(M$-RR)
M18R+1#<PB460BT0W-(E%E(M$-SB)19B+1#<\B46<C85$____Z([:__^)V(UV
M0"GP@_@_#X]>____C5O`B=C!Z`:)PL'B!BG3C7PZ0(V58/___\=$)`Q$````
MB5PD"(E\)`2)%"3HK=7__XE=H.E=_O__D(UT)@"+E01___^+G?Q^__^)%"3H
M/-?__XNU6/___XN57/___XGPP>@#@^`_QH0%8/___X"#P`&#^#@/CKD!``"Y
M0````(V]8/___RG!`?B)3"0(B97X?O__QT0D!`````")!"3H"]7__XV%1/__
M_^C0V?__N0X````QP(N]]'[___.KBY7X?O__B="(59O!Z!B-?:>(19B)T,'H
M$(A%F8G0P>@(B$6:B?#!Z!B(19R)\,'H$(A%G8GPP>@(B$6>B?"(19^-A43_
M___H==G__XN51/___S'VB=&(5=/!Z1B)R(A-T(G1P>D0B$W1B='!Z0B+E4C_
M__^(3=*)T<'I&(A5UXA-U(G1P>D0B$W5B='!Z0B+E4S___^(3=:)T<'I&(A5
MVXA-V(G1P>D0B$W9B='!Z0B+E5#___^(3=J)T<'I&(A5WXA-W(G1P>D0B$W=
MB='!Z0B+E53___^(3=Z)T<'I&(A5XXA-X(G1P>D0B$WAB='!Z0B(3>+K!V:0
M#[9$-=`/ML"-=@&)/"2)1"00QT0D#+3/!`C'1"0(_____\=$)`0!````C7\"
MZ*;6__^#_A1UR<9%SP#'1"0<Y<\$"(U5IXL]4-`$"(E4)!B)?"04B5PD$,=$
M)`RESP0(QT0D"/_____'1"0$`0```(D<).A@UO__Z;SZ__^Y.````(V]8/__
M_RG!`?B)E?A^__^)3"0(QT0D!`````")!"3H4M/__XN5^'[__^E<_O__@+U&
M?___00^%P/O__X"]1W___T,/A;/[__^`O4A___](#X6F^___@+U)?___10^%
MF?O__XN]!'___\=$)`P"````QT0D!,;____'1"0(_____XD\).BMTO__C85$
M?___QT0D""D```")1"0$B3PDZ"/3___'1"0<Y<\$"(V51'___^D.____B<?I
M^/?__^CDU/__C70F`%6)Y5=64XUD)-3'!"0`````Z.K5__^+`(D$).C0TO__
MB00DZ$C3___&``&XM,X$".BKY/__A<!T"8`X,0^$'@0``.A9[___QP0D````
M`.BMU?__BP")!"3HD]+__XD$),=$)`P+````QT0D"`$```#'1"0$W\\$".@C
MTO__A<`/A&8!``"+4`@/MLJ#Z0F#^0$/A]L&``"!X@#```"!^@"````/A:D'
M``"+0`R+0!B)1>2AR%4%"(/X`0^.&`$``#'VNP$```#K:(VT)@`````/MM"#
M^@0/AJX%``"#^@L/A-T%``"#^@P/A+@%```E`,```#T`@```#X2R````BT<,
MBQ7,504(BQ2:B40D!(D4).@*U?__A<`/A;H"``"-6P&AR%4%"#G8C78!#XZO
M````QP0D`````.C#U/__BP")!"3HJ='__XM5Y,=$)`P`````B70D"(E4)`2)
M!"3H#M/__X7`#X1N`@``BSB+1PCVQ`0/A5C____'!"0`````Z'S4__^+`(D$
M).ABT?__B00DQT0D#`(```#'1"0(`````(E\)`3HQM3__^E2____D(U2]X/Z
M`0^'0O___\=$)`@B````QT0D!#32!`C'!"3`T`0(Z'C3__\Q]HVV`````(U0
M_SGR#X0M`@``QP0D`````.@)U/__BP")!"3H[]#__XD$),=$)`P%````QT0D
M"`$```#'1"0$Y,\$".A_T/__A<")PP^$@@```(M`"`^VT(/J"8/Z`0^'B04`
M`"4`P```/0"````/A5T%``"+0PR+,,<$)`````#HHM/__XL`B00DZ(C0__^)
M!"3'1"0(YL\$"(ET)`3H1-#__XM#"`^VT(/J"8/Z`0^'R`0``"4`P```/0"`
M```/A5P$``"+0PR+&/9#"D`/A4,!``#'!"0`````Z$?3__^+`(D$).@MT/__
MB00DQT0D#`4```#'1"0(`0```,=$)`0,SP0(Z+W/__^%P(G#=&&X[<X$".CM
MX?__A<")Q@^$A@(``(M#"`^VT(/J"8/Z`0^'*P0``"4`P```/0"````/A6\$
M``"+0PR+.,<$)`````#HT-+__XL`B00DZ+;/__^)!"2)="0(B7PD!.AVS___
MQP0D`````.BJTO__BP")!"3HD,___XD$).@(T/__Q@``QP0D`````.B)TO__
MBP")!"3H;\___XD$).BGTO__QP``````N-#.!`CH1^'__X7`H\15!0@/A,\`
M``#'1"0$[0$``(D$).CZS?__@_@1=`V%P'0)@_C_#X5.`P``C60D+%M>7UW#
MC;0F`````*'(504(C5#_.?(/A0/^___K+HVV`````,<$)`````#H!-+__XL`
MB00DZ.K.__^)!"2)7"0$Z+[0___IEO[__Y"#^`$/CLK]__^[`0```&:0QP0D
M`````(U;`>C)T?__BP")!"3HK\[__XM5Y(D$)(E4)`3H0,[__SD=R%4%"'_0
MZ8[]__^-=@"`>`$`#X3=^___C;8`````Z<W[__^AS%4%"(D$).B>\O__H\15
M!0B+0P@/MM"+/<Q5!0B#Z@F#^@$/AW<$```E`,```#T`@```#X5+!```BT,,
MBS"+1@CVQ`0/A$\!```/MM"#^@0/AA($``"#^@L/A.T#``"#^@P/A)`#```E
M`,```#T`@```#X18`0``BT8,B7PD!(D$).@3S___B<:+0P@/MM"#Z@F#^@$/
MAY4#```E`,```#T`@```#X5I`P``BT,,BQB+0PCVQ`0/A:,```#'!"0`````
MZ,+0__^+`(D$).BHS?__B00DQT0D#`(```#'1"0(`````(E<)`3H#-'__XE$
M)`BAS%4%"(ET)`R+`,<$)-S2!`B)1"0$Z,W/__^AS%4%"(LXBT,(#[;0@^H)
M@_H!#X>:`@``)0#````]`(````^%;@(``(M##(LPQP0D`````.A#T/__BP")
M!"3H*<W__XGYB?+HP-___^EU_?__#[;0@_H$#X8=`@``@_H+#X3X`0``@_H,
M#X3K````)0#````]`(```'4(C5+W@_H!=F>+0PSI5?___\<$)`````#HY<__
M_XL`B00DZ,O,__^)!"3'1"0,`@```,=$)`@`````B70D!.@OT/__Z:O^__^-
M4O>#^@$/AYS^___'1"0(;````,=$)`0TT@0(QP0DP-`$".CBSO__QT0D"&X`
M``#'1"0$--($",<$),#0!`CHQL[__\=$)`@B````QT0D!*31!`C'!"3`T`0(
MZ*K.___'1"0((@```,=$)`0$T@0(QP0DP-`$".B.SO__QT0D""(```#'1"0$
MU-$$",<$),#0!`CH<L[__\=$)`AN````QT0D!`32!`C'!"3`T`0(Z%;.___'
M1"0(,@```,=$)`3TT`0(QP0DP-`$".@ZSO__B40D#*'$504(B40D"*',504(
MBP#'!"0,TP0(B40D!.@6SO__QT0D"#@```#'1"0$6-`$",<$),#0!`CH^LW_
M_\=$)`@R````QT0D!%C0!`C'!"3`T`0(Z-[-___'1"0('@```,=$)`18T`0(
MQP0DP-`$".C"S?__QT0D"#@```#'1"0$]-`$",<$),#0!`CHILW__\=$)`@P
M````QT0D!/30!`C'!"3`T`0(Z(K-___'1"0(,````,=$)`18T`0(QP0DP-`$
M".ANS?__QT0D"&X```#'1"0$U-$$",<$),#0!`CH4LW__\=$)`AN````QT0D
M!*31!`C'!"3`T`0(Z#;-___'1"0(/````,=$)`3TT`0(QP0DP-`$".@:S?__
MQT0D"#P```#'1"0$6-`$",<$),#0!`CH_LS__\=$)`@>````QT0D!/30!`C'
M!"3`T`0(Z.+,___'1"0(;````,=$)`0$T@0(QP0DP-`$".C&S/__QT0D"&X`
M``#'1"0$]-`$",<$),#0!`CHJLS__\=$)`AN````QT0D!%C0!`C'!"3`T`0(
MZ([,___'1"0(;````,=$)`34T00(QP0DP-`$".ARS/__QT0D"&P```#'1"0$
MI-$$",<$),#0!`CH5LS__\=$)`AL````QT0D!/30!`C'!"3`T`0(Z#K,___'
M1"0(;````,=$)`18T`0(QP0DP-`$".@>S/__C;0F`````(V\)P````!5B>6-
M9"3HQP0D`````.BMS/__BP")!"3HD\G__XD$),=$)`SKSP0(QT0D"!"7!`C'
M1"0$]<\$".ACS/__R<.058GEC60DV,<$)`````#H;<S__XL`B00DZ%/)__^)
M!"3HF____\<$)`````#H3\S__XL`B00DZ#7)__^)!"3'1"04`````,=$)!#E
MSP0(QT0D#.7/!`C'1"0(8,,$",=$)`01T`0(Z.7)___)PY"0D%6)Y5/H,@``
M`('#LW8``(/L$(N#7(K__XE$)`R+11")1"0(BT4,B40D!(M%"(D$).@[R/__
M@\006UW#BQPDPY!5B>5=PXUT)@"-O"<`````58GE5U93Z.#___^!PV%V``"#
M[!SHY\;__XV[V/[__XV#V/[__RG'P?\"A?]T)#'VBT40B40D"(M%#(E$)`2+
M10B)!"3_E+/8_O__@\8!.?YRWH/$'%M>7UW#D)"0D)"058GE4XUD)/RAY$(%
M"(/X_W02N^1"!0B0C5O\_]"+`X/X_W7TC60D!%M=PY!5B>53@^P$Z`````!;
M@</4=0``Z,S+__]96\G#`````````````````````````````````P````$`
M`@``````4$%27T-,14%.`"]P<F]C+W-E;&8O97AE`"XN`"5S+R5S`"]P<F]C
M+R5I+R5S`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$`%!!4E]414U0`%!!4E]$14)51P!005)?0T%#2$4`
M4$%27U!23T=.04U%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,3T)!3%]$
M14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!P87(M`"UE`"TM
M`$,Z7%1%35``+W1M<`!414U01$E2`%1-4`!54T52`%5315).04U%`"5S)7,E
M<R5S`"5S)7-C86-H92TE<R5S`"4P,G@`)7,E<W1E;7`M)74E<P`E<R5S=&5M
M<"TE=2TE=25S`%-94U1%30!!4D=6`!@`<&5R;`!P97)L>'-I+F,`1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"\`
M.@```%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@`````";0!`@H
MT`0(*"AS=G1Y<&4I*"AS:'!L97`I+3YS=E]F;&%G<R`F(#!X9F8I*2`]/2!3
M5G1?4%9'5B!\?"`H*'-V='EP92DH*'-H<&QE<"DM/G-V7V9L86=S("8@,'AF
M9BDI(#T](%-6=%]05DQ6``!!<W-E<G1I;VX@)7,@9F%I;&5D.B!F:6QE(")I
M;G1E<FYA;',N8R(L(&QI;F4@)60`````*"@H*'-H<&QE<"DM/G-V7V9L86=S
M("8@*#!X,#`P,#0P,#!\,'@P,#`P.#`P,"DI(#T](#!X,#`P,#@P,#`I("8F
M("@H*'-V='EP92DH*'-H<&QE<"DM/G-V7V9L86=S("8@,'AF9BDI(#T](%-6
M=%]05D=6('Q\("@H<W9T>7!E*2@H<VAP;&5P*2T^<W9?9FQA9W,@)B`P>&9F
M*2D@/3T@4U9T7U!63%8I*0`````H*'-V='EP92DH*%]S=FDI+3YS=E]F;&%G
M<R`F(#!X9F8I*2`^/2!35G1?4%8````H*'-V='EP92DH*%]S=FDI+3YS=E]F
M;&%G<R`F(#!X9F8I*2`A/2!35G1?4%9!5@`H*'-V='EP92DH*%]S=FDI+3YS
M=E]F;&%G<R`F(#!X9F8I*2`A/2!35G1?4%9(5@`A*"@H*%]S=FDI+3YS=E]F
M;&%G<R`F("@P>#`P,#`T,#`P?#!X,#`P,#@P,#`I*2`]/2`P>#`P,#`X,#`P
M*2`F)B`H*"AS=G1Y<&4I*"A?<W9I*2T^<W9?9FQA9W,@)B`P>&9F*2D@/3T@
M4U9T7U!61U8@?'P@*"AS=G1Y<&4I*"A?<W9I*2T^<W9?9FQA9W,@)B`P>&9F
M*2D@/3T@4U9T7U!63%8I*0`E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M
M(&%B;W)T:6YG('=I=&@@)6DN"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T
M96UP;W)A<GD@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I
M=&@@)6DN"@```````````(#____/07!A<BYP;```````````````````````
M`",A+W5S<B]B:6XO<&5R;`H*979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M
M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C
M<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE
M("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3D*"FUY("@D<&%R7W1E;7`L
M("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%
M04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D[
M"B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M
M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U
M<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y
M:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE
M("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@
M=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@
M("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES
M86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N
M9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@
M8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL
M97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@
M("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U
M<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@
M8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I
M;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L
M"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@
M("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@
M)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@
M+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE
M.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O
M;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES
M=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD
M('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N
M("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X
M:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@
M>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@
M)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P
M?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L
M971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I
M;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*
M7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD
M(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O
M<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S
M=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D
M871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@
M;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@
M<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L
M87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&
M2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&
M2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@
M(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R
M>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E
M<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@
M(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI
M;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M
M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U
M9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<
M+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@
M)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@
M("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[
M"B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@
M("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@
M)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@
M("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U
M;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]
M?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2![
M"B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I
M"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D
M8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE
M;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL
M96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@
M("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E
M("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(
M96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@
M("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L
M"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@
M("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@
M("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@
M("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N
M86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@
M("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK97ES
M("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S
M("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L
M87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R
M971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL
M96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@
M("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F
M:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*
M("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@96QS
M92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H
M)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U
M="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@
M("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@
M("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@
M("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN
M;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W
M(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE
M('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E
M<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ
M2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T
M<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q
M=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@
M:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=]
M(#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE
M<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I
M('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X
M96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@
M9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE
M;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F
M(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`
M<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N
M86UE*3L*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*"B,@
M1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B
M;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@
M(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@
M("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?
M<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P
M87(*("`@("D["@H@("`@;7D@0&%D9%]T;U]I;F,["B`@("!W:&EL92`H0$%2
M1U8I('L*("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PH*("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@
M("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@(&5V86P@(G5S
M92`D,B(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*
M("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("1O=70@
M/2`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@
M("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@('T*("`@("`@
M("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("1B=6YD;&4@/2`G
M86QL)SL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@
M("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB
M+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@
M("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@
M)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("!]"@H@("`@("`@('-H:69T*$!!
M4D=6*3L*"B`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"B`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@
M("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES
M=#L*("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["B`@("`@("`@("`@(&5X:70["B`@("`@("`@?0H@("`@?0H*
M("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*"B,@6%A8("TM(&%D
M9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@
M*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@("`C
M;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU3
M5VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q
M=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]('-H:69T
M*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I
M('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N
M;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@
M("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A
M(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II
M<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@
M>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@
M("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*
M("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C
M86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@
M;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@
M("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!
M4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*
M("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?
M5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B
M:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@
M7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M
M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@
M("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D
M,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I
M('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@
M("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@
M("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?
M(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@
M("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE
M;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN
M="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@
M5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*
M("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["@H@
M("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@
M<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*
M("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@("`@
M("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R
M"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X
M<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I
M=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@:68@*"1#;VYF
M:6=[7V1E;&EM?2!E<2`G7%PG*2![('-[7%Q]>R]]9R!F;W(@0&EN8R!]"@H@
M("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q
M-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?
M/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@
M("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P97(@
M9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE87-E
M(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@
M:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N("TM(%-T969F96X*("`@
M("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@
M86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S
M>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@
M/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T
M96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@
M("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E
M86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M
M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@
M("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>
M*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@
M("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@
M("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO
M9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I
M;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T
M96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O
M=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@
M("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY
M("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@
M("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N
M($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D
M(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@
M("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S
M92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@
M("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<
M+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@("`C($1O(&YO="!L
M970@6%-,;V%D97(@<&EC:R!U<"!A=71O+RH@9G)O;2!E;G9I<F]N;65N=`H@
M("`@("`@("`@("`@("`@)&-O;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL
M97-S("LN*B]G;W1O(')E=')Y.R\*("`@("`@("`@("`@("`@("`@("!I9B!L
M8R@D;F%M92D@97$@;&,H(EA33&]A9&5R+G!M(BD["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@
M("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H
M+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@
M("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F
M:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]
M"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN
M9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z
M:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@
M("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R
M:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*
M("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q
M("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@
M("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@
M("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D[
M"B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH
M97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N
M86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*
M("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@
M)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*
M("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!0
M05(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L
M;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H
M92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W
M9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@
M("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E
M.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@
M("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E
M<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@
M=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@
M("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#
M;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@
M*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@
M("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M
M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]4
M14U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T
M<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA
M;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G
M<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N
M;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=
M(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@
M("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@
M/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&
M:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q
M=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E
M(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R
M;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@
M("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@
M(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E
M<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`[
M"B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R
M.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4[
M"B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!0
M05(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ
M1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@
M979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS
M,B!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V
M86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["GT*"B,@
M5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M
M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2.CI3971U
M<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@
M>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@
M("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P871H("@*
M("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M
M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)'!A
M=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E
M<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@
M=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@
M/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<
M5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?
M9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L
M(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@("`@(&]P
M96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@("!S965K
M("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@;7D@)&)U
M9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B*2!["B`@
M("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@("`@("`@
M("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@("`@)&)U
M9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I
M('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@("`@
M("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@
M8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("`@("`@
M("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%
M4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO
M;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@
M("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I
M(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N
M*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@("1C
M='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8VQO
M<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D9F@I.PH@
M("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.5GM005)?
M0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.5GM005)?
M5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]("0Q(&EF
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\[
M"GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I(#T@0%\[
M"B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M92`]("(D
M<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI
M('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*
M("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]"B`@("!E
M;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M
M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE
M;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R971U<FXH
M)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E<R!I;B!005(Z
M.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M
M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA
M;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF
M("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!
M4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D
M<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@
M("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@
M("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@("`@:68@
M*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D
M<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N
M.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@
M("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@
M)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?
M9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@
M("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*
M<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@
M:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@
M)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@
M(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^
M(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[
M7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E
M;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@
M?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(
M12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D
M14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-
M4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,
M3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y6
M7U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM0
M05)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@
M("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.
M?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q
M,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y]
M(#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*
M?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D
M;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@
M("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@
M:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@
M("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@
M("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN
M('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D
M<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@
M)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*"C$["@HC;&EN92`Q,#`R"@I?7T5.1%]?"@````$;`SOH````
M'````+!M__\$`0``\&W__RP!``"@>O__7`$``%![__^,`0``<'O__ZP!``#`
M>___V`$```!\__\``@```'W__S`"``!@??__4`(``+!___]X`@``0('__[@"
M```0@O__Z`(``.""__\8`P``\(+__S@#``#@A/__>`,``!"&__^L`P``D(?_
M_]@#``"PA___^`,``,"(__\P!```0(G__VP$``!@B___K`0``)"-___<!```
M<);__Q`%``"PG___0`4``/"?__]@!0``8*#__X`%``"@H/__I`4``+"@___$
M!0``%``````````!>E(``7P(`1L,!`2(`0``)````!P```"D;/__,P````!!
M#@A"A0(-!46#!(8#:,-!QD'%#`0$`"P```!$````O&S__ZL,````00X(1(4"
M#05#AP-*A@15@P4#@`S#0<9!QT'%#`0$`"P```!T````/'G__ZP`````00X(
M0H4"#051AP.&!(,%4@H-!,?&PT'%#@1!"P```!P```"D````O'G__Q$`````
M00X(0H4"#05-Q0P$!```*````,0```"\>?__1`````!!#@A"A0(-!4\*Q0P$
M!$8+8PH,!`3%10L````D````\````.!Y__\]`````$$."$*%`@T%0X8#1(,$
M<,-!QD'%#`0$+````!@!``#X>?__\P````!!#@A"A0(-!6R'`X8$@P4"@0H-
M!,?&PT'%#@1'"P``'````$@!``#(>O__70````!!#@A"A0(-!0)9Q0P$!``D
M````:`$```A[__](`@```$$."$*%`@T%3(,#`S<"PT'%#`0$````/````)`!
M```P??__A0$```!!#@A"A0(-!4.'`TV#!88$30K#0<9!QT'%#`0$10L#"`$*
MPT'&0<=!#`0$Q44+`"P```#0`0``@'[__\D`````00X(0H4"#05#@P,"00K#
M0<4,!`1("P)WPT$,!`3%`"P``````@``('___\0`````00X(0H4"#05AAP.&
M!(,%`E`*#03'QL-!Q0X$0PL``!P````P`@``P'___PT`````00X(0H4"#05%
MQ0P$!```/````%`"``"P?___[0$```!!#@A"A0(-!42&!(<#18,%`E$*PT'&
M0<=!Q0P$!$@+`ET*PT'&0<=!#`0$Q4@+`#````"0`@``8('__R@!````00X(
M0H4"#05&AP-$A@1&@P4"?PK#0<9!QT'%#`0$0PL````H````Q`(``%R"__]U
M`0```$$."$*%`@T%`F&&!(<#`L,*QD''0<4,!`1'"QP```#P`@``L(/__R``
M````00X(0H4"#05<Q0P$!```-````!`#``"P@___$`$```!!#@A"A0(-!4F#
M!(8#`E8*PT'&0<4,!`1,"UH*PT'&0<4,!`1$"P`X````2`,``(B$__]^````
M`$$."$*%`@T%2H,%A@2'`P)>"L-!QD''0<4,!`1!"T?#0<9!QT'%#`0$```\
M````A`,``,R$__\8`@```$$."$*%`@T%71`#"'4`"?`:"?@B$`8(=0`)\!H)
M_"(#EP$*PT'&0@T$0<4.!$4++````,0#``"LAO__*`(```!!#@A"A0(-!6>#
M!88$AP,"40K#0<9!QT'%#`0$00L`,````/0#``"LB/__W`@```!!#@A"A0(-
M!0*F@P6&!(<#`UH""L-!QD''0<4,!`1""P```"P````H!```6)'__S()````
M00X(0H4"#05.@P6&!(<#`[P#"L-!QD''0<4,!`1("QP```!8!```:)K__S\`
M````00X(0H4"#05[Q0P$!```'````'@$``"(FO__;0````!!#@A"A0(-!0)I
MQ0P$!``@````F`0``-B:__\[`````$$."$*%`@T%3(,#:L-!Q0P$!``<````
MO`0``/2:__\%`````$$."$*%`@T%0<4,!`0``"@```#<!```Y)K__UH`````
M00X(0H4"#05.@P6&!(<#`D7#0<9!QT'%#`0$`````/____\`````_____P``
M`````````0````$````!````K0(```$```"\`@```0```,@"```!````TP(`
M``$```#=`@```0```.L"```!````^`(```$```!'`P``#P```*T$```,````
MH)0$"`T````LS@0(]?[_;XR!!`@%````)(H$"`8```#D@@0("@```%H&```+
M````$````!4``````````P````Q$!0@"````@`(``!0````1````%P```""2
M!`@1````")($"!(````8````$P````@```#^__]O:)$$"/___V\"````\/__
M;WZ0!`@`````````````````````````````````````````````````````
M````````````````^$(%"```````````YI0$"/:4!`@&E00(%I4$"":5!`@V
ME00(1I4$"%:5!`AFE00(=I4$"(:5!`B6E00(II4$"+:5!`C&E00(UI4$".:5
M!`CVE00(!I8$"!:6!`@FE@0(-I8$"$:6!`A6E@0(9I8$"':6!`B&E@0(EI8$
M"*:6!`BVE@0(QI8$"-:6!`CFE@0(]I8$"`:7!`@6EP0()I<$"#:7!`A&EP0(
M5I<$"&:7!`AVEP0(AI<$"):7!`BFEP0(MI<$",:7!`C6EP0(YI<$"/:7!`@&
MF`0(%I@$"":8!`@VF`0(1I@$"%:8!`AFF`0(=I@$"(:8!`B6F`0(II@$"+:8
M!`C&F`0(UI@$".:8!`CVF`0(!ID$"!:9!`@FF00(-ID$"$:9!`A6F00(9ID$
M"':9!`B&F00(EID$"*:9!`BVF00(QID$"-:9!`@`````_____VC3!`AM60``
M`$=#0SH@*$=.52D@-"XT+C$@,C`P.3`Y,3@@*%)E9"!(870@-"XT+C$M,34I
M``!'0T,Z("A'3E4I(#0N-"XQ(#(P,#DP.3$X("A2960@2&%T(#0N-"XQ+3$U
M*0``1T-#.B`H1TY5*2`T+C0N,2`R,#`Y,#DQ."`H4F5D($AA="`T+C0N,2TQ
M-2D``$=#0SH@*$=.52D@-"XT+C$@,C`P.3`Y,3@@*%)E9"!(870@-"XT+C$M
M,34I``!'0T,Z("A'3E4I(#0N-"XQ(#(P,#DP.3$X("A2960@2&%T(#0N-"XQ
M+3$U*0``1T-#.B`H1TY5*2`T+C0N,2`R,#`Y,#DQ."`H4F5D($AA="`T+C0N
M,2TQ-2D``$=#0SH@*$=.52D@-"XT+C$@,C`P.3`Y,3@@*%)E9"!(870@-"XT
M+C$M,34I``!'0T,Z("A'3E4I(#0N-"XQ(#(P,#DP.3$X("A2960@2&%T(#0N
M-"XQ+3$U*0``1T-#.B`H1TY5*2`T+C0N,2`R,#`Y,#DQ."`H4F5D($AA="`T
M+C0N,2TQ-2D``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO
M=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI
M;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A
M;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`
M+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````````````
M```````````````````````+`````0````(````T@00(-`$``!,`````````
M``````$`````````$P````<````"````2($$"$@!```@```````````````$
M`````````"$````'`````@```&B!!`AH`0``)```````````````!```````
M```T````]O__;P(```",@00(C`$``%@!```%``````````0````$````/@``
M``L````"````Y(($".0"``!`!P``!@````$````$````$````$8````#````
M`@```"2*!`@D"@``6@8``````````````0````````!.````____;P(```!^
MD`0(?A```.@````%``````````(````"````6P```/[__V\"````:)$$"&@1
M``"@````!@````(````$`````````&H````)`````@````B2!`@($@``&```
M``4`````````!`````@```!S````"0````(````@D@0((!(``(`"```%````
M#`````0````(````?`````$````&````H)0$"*`4```P```````````````$
M`````````'<````!````!@```-"4!`C0%```$`4`````````````!`````0`
M``""`````0````8```#@F00(X!D``$PT`````````````!``````````B```
M``$````&````+,X$""Q.```<```````````````$`````````(X````!````
M`@```&#.!`A@3@``CEX`````````````(`````````"6`````0````(```#P
M+`4(\*P``.P```````````````0`````````I`````$````"````W"T%"-RM
M```(!0`````````````$`````````*X````!`````P```.1"!0CDL@``"```
M````````````!`````````"U`````0````,```#L0@4([+(```@`````````
M``````0`````````O`````$````#````]$(%"/2R```$```````````````$
M`````````,$````&`````P```/A"!0CXL@``$`$```8`````````!`````@`
M``#*`````0````,````(1`4("+0```0```````````````0````$````SP``
M``$````#````#$0%"`RT``!,`0`````````````$````!````-@````!````
M`P```%A%!0A8M0``$```````````````!`````````#>````"`````,```"`
M104(:+4``%`0`````````````"``````````XP````$``````````````&BU
M``">`0`````````````!``````````$````#```````````````&MP``[```
1`````````````0``````````
